@@ -2,14 +2,16 @@
 #'
 #' @export
 #' @param id (character) The EOL data object identifier
-#' @param usekey (logical) use your API key or not (TRUE or FALSE)
+#' @param taxonomy (logical) Whether to return any taxonomy details from different
+#' taxon hierarchy providers, in an array named \code{taxonconcepts}
+#' @param usekey (logical) use your API key or not (\code{TRUE} or \code{FALSE})
 #' @param key (character) Your EOL API key; can load from .Rprofile if not passed as a parameter
 #' @param verbose (logical); If TRUE the actual taxon queried is printed on the
 #'    console.
 #' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #' @details It's possible to return JSON or XML with the EOL API. However,
 #' 		this function only returns JSON for now.
-#' @return List or dataframe (default).
+#' @return A list, optionally with a data.frame if \code{taxonomy=TRUE}
 #' @examples \dontrun{
 #' eol_dataobjects(id = "d72801627bf4adf1a38d9c5f10cc767f")
 #' eol_dataobjects(id = "21929584")
@@ -18,16 +20,17 @@
 #' library("httr")
 #' eol_dataobjects(id = "21929584", config = verbose())
 #' }
-eol_dataobjects <- function(id, usekey = TRUE, key = NULL, verbose = TRUE, ...) {
+eol_dataobjects <- function(id, taxonomy = TRUE, usekey = TRUE, key = NULL, verbose = TRUE, ...) {
   if (usekey) key <- getkey(key, "eolApiKey")
-  tt <- GET(file.path(eol_url("data_objects"), paste0(id, ".json")), query = argsnull(tc(list(key = key))),
-            ...)
+  tt <- GET(file.path(eol_url("data_objects"), paste0(id, ".json")),
+            query = argsnull(tc(list(key = key, taxonomy = as_l(taxonomy)))), ...)
   stop_for_status(tt)
-  res <- content(tt, as = "text")
-  tmp <- jsonlite::fromJSON(res)
+  tmp <- jsonlite::fromJSON(con_utf8(tt))
   tmp <- nmslwr(tmp)
-  tmp$taxonconcepts <- nmslwr(tmp$taxonconcepts)
-  tmp$dataobjects <- nmslwr(tmp$dataobjects)
+  if (taxonomy) {
+    tmp$taxonconcepts <- nmslwr(tmp$taxonconcepts)
+    tmp$taxonconcepts$taxonrank <- tolower(tmp$taxonconcepts$taxonrank)
+  }
   return(tmp)
 }
 
