@@ -130,10 +130,12 @@ ncbi_foo <- function(x, ...){
   baseurl <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi?db=taxonomy"
   ID <- paste("ID=", x, sep = "")
   searchurl <- paste(baseurl, ID, sep = "&")
-  tt <- content(GET(searchurl, ...), "text")
-  ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
+  tt <- GET(searchurl, ...)
+  stop_for_status(tt)
+  res <- con_utf8(tt)
+  ttp <- xml2::read_xml(res)
   # common name
-  out <- xpathSApply(ttp, "//TaxaSet/Taxon/OtherNames/GenbankCommonName", xmlValue)
+  out <- xml_text(xml_find_all(ttp, "//TaxaSet/Taxon/OtherNames/GenbankCommonName"))
   # NCBI limits requests to three per second
   Sys.sleep(0.33)
   return(out)
